==> openflowplugin-extension-nicira-0.6.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/NxActionResubmitGrouping.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.resubmit.grouping.NxResubmit;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * grouping nx-action-resubmit-grouping {
 *     container nx-resubmit {
 *         leaf in-port {
 *             type in-port;
 *         }
 *         leaf table {
 *             type table;
 *         }
 *     }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nx-action-resubmit-grouping</i>
 *
 */
public interface NxActionResubmitGrouping
    extends
    DataObject
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "nx-action-resubmit-grouping").intern();

    /**
     * Re-searches OpenFlow flow table (or the table whose number is specified by 
     * table)with the in-port field replaced by port (if port is specified) and 
     * executes the actions found
     *
     *
     *
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.resubmit.grouping.NxResubmit</code> <code>nxResubmit</code>, or <code>null</code> if not present
     */
    NxResubmit getNxResubmit();

}

==> openflowplugin-extension-nicira-0.7.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/NxActionResubmitGrouping.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714;
import javax.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.resubmit.grouping.NxResubmit;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * grouping nx-action-resubmit-grouping {
 *   container nx-resubmit {
 *     leaf in-port {
 *       type uint16;
 *       default 0xfff8;
 *     }
 *     leaf table {
 *       type uint8 {
 *         range "0 .. 255";
 *       }
 *       default 255;
 *     }
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nx-action-resubmit-grouping</i>
 *
 */
public interface NxActionResubmitGrouping
    extends
    DataObject
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-resubmit-grouping");

    /**
     * Re-searches OpenFlow flow table (or the table whose number is specified by 
     * table)with the in-port field replaced by port (if port is specified) and 
     * executes the actions found
     *
     *
     *
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.resubmit.grouping.NxResubmit</code> <code>nxResubmit</code>, or <code>null</code> if not present
     */
    @Nullable
    NxResubmit getNxResubmit();

}
